==> jc-1.4.0.tar.gz: soot/tagkit/DoubleConstantValueTag.h <==
// public class soot.tagkit.DoubleConstantValueTag

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class 5325ccd48da9d2b8 soot_tagkit_DoubleConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_DoubleConstantValueTag_H_
#define _JC_soot_tagkit_DoubleConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$sub_refs	_jc_soot_tagkit_DoubleConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$sub_nonrefs	_jc_soot_tagkit_DoubleConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$refs	_jc_soot_tagkit_DoubleConstantValueTag$refs;
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$nonrefs	_jc_soot_tagkit_DoubleConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$object	_jc_soot_tagkit_DoubleConstantValueTag$object;

typedef const struct _jc_soot_tagkit_DoubleConstantValueTag$vmethods	_jc_soot_tagkit_DoubleConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_DoubleConstantValueTag$vtable	_jc_soot_tagkit_DoubleConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_DoubleConstantValueTag$vtype	_jc_soot_tagkit_DoubleConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_DoubleConstantValueTag$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *, jlong);

// Virtual methods
extern jdouble _jc_soot_tagkit_DoubleConstantValueTag$method$getDoubleValue$808cfd1a28dc9ae3(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *);
extern jlong _jc_soot_tagkit_DoubleConstantValueTag$method$getRawBits$7cc3acae4ffe3b68(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_DoubleConstantValueTag$method_info$getDoubleValue$808cfd1a28dc9ae3;
extern _jc_method _jc_soot_tagkit_DoubleConstantValueTag$method_info$getRawBits$7cc3acae4ffe3b68;

// Virtual methods structure
struct _jc_soot_tagkit_DoubleConstantValueTag$vmethods {
	jdouble	(*getDoubleValue$808cfd1a28dc9ae3)(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *);
	jlong	(*getRawBits$7cc3acae4ffe3b68)(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *);
};

// Vtable
struct _jc_soot_tagkit_DoubleConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_DoubleConstantValueTag$vmethods	soot_tagkit_DoubleConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_DoubleConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_DoubleConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_DoubleConstantValueTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_DoubleConstantValueTag$refs {
    _jc_soot_tagkit_DoubleConstantValueTag$sub_refs	soot_tagkit_DoubleConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_DoubleConstantValueTag$sub_nonrefs {
	jlong	value;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_DoubleConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_DoubleConstantValueTag$sub_nonrefs	soot_tagkit_DoubleConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_DoubleConstantValueTag$object {
	_jc_soot_tagkit_DoubleConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_DoubleConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_DoubleConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_DoubleConstantValueTag$vtype _jc_soot_tagkit_DoubleConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_DoubleConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_DoubleConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_DoubleConstantValueTag_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/DoubleConstantValueTag.h <==
// public class soot.tagkit.DoubleConstantValueTag

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 927f75e1f2873cee soot_tagkit_ConstantValueTag
// @dep_class 5325ccd48da9d2b8 soot_tagkit_DoubleConstantValueTag

// header file dependencies
// @dep_header soot_tagkit_ConstantValueTag

#include "soot/tagkit/ConstantValueTag.h"

#ifndef _JC_soot_tagkit_DoubleConstantValueTag_H_
#define _JC_soot_tagkit_DoubleConstantValueTag_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$sub_refs	_jc_soot_tagkit_DoubleConstantValueTag$sub_refs;
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$sub_nonrefs	_jc_soot_tagkit_DoubleConstantValueTag$sub_nonrefs;
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$refs	_jc_soot_tagkit_DoubleConstantValueTag$refs;
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$nonrefs	_jc_soot_tagkit_DoubleConstantValueTag$nonrefs;
typedef struct _jc_soot_tagkit_DoubleConstantValueTag$object	_jc_soot_tagkit_DoubleConstantValueTag$object;

typedef const struct _jc_soot_tagkit_DoubleConstantValueTag$vmethods	_jc_soot_tagkit_DoubleConstantValueTag$vmethods;
typedef const struct _jc_soot_tagkit_DoubleConstantValueTag$vtable	_jc_soot_tagkit_DoubleConstantValueTag$vtable;
typedef const struct _jc_soot_tagkit_DoubleConstantValueTag$vtype	_jc_soot_tagkit_DoubleConstantValueTag$vtype;

// Constructors
extern void _jc_soot_tagkit_DoubleConstantValueTag$method$_init$8de6a0a3bec04d2a(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *, jlong) _JC_JCNI_ATTR;

// Virtual methods
extern jdouble _jc_soot_tagkit_DoubleConstantValueTag$method$getDoubleValue$808cfd1a28dc9ae3(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *) _JC_JCNI_ATTR;
extern jlong _jc_soot_tagkit_DoubleConstantValueTag$method$getRawBits$7cc3acae4ffe3b68(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_DoubleConstantValueTag$method_info$getDoubleValue$808cfd1a28dc9ae3;
extern _jc_method _jc_soot_tagkit_DoubleConstantValueTag$method_info$getRawBits$7cc3acae4ffe3b68;

// Virtual methods structure
struct _jc_soot_tagkit_DoubleConstantValueTag$vmethods {
	jdouble	(*getDoubleValue$808cfd1a28dc9ae3)(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *) _JC_JCNI_ATTR;
	jlong	(*getRawBits$7cc3acae4ffe3b68)(_jc_env *, struct _jc_soot_tagkit_DoubleConstantValueTag$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_DoubleConstantValueTag$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_ConstantValueTag$vmethods	soot_tagkit_ConstantValueTag;
	_jc_soot_tagkit_DoubleConstantValueTag$vmethods	soot_tagkit_DoubleConstantValueTag;
};

// Vtype
struct _jc_soot_tagkit_DoubleConstantValueTag$vtype {
	_jc_type			type;
	_jc_soot_tagkit_DoubleConstantValueTag$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_DoubleConstantValueTag$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_DoubleConstantValueTag$refs {
    _jc_soot_tagkit_DoubleConstantValueTag$sub_refs	soot_tagkit_DoubleConstantValueTag;
    _jc_soot_tagkit_ConstantValueTag$sub_refs	soot_tagkit_ConstantValueTag;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_DoubleConstantValueTag$sub_nonrefs {
	jlong	value;
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_DoubleConstantValueTag$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_ConstantValueTag$sub_nonrefs	soot_tagkit_ConstantValueTag;
    _jc_soot_tagkit_DoubleConstantValueTag$sub_nonrefs	soot_tagkit_DoubleConstantValueTag;
};

// Object instance structure
struct _jc_soot_tagkit_DoubleConstantValueTag$object {
	_jc_soot_tagkit_DoubleConstantValueTag$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_DoubleConstantValueTag$vtype	*vtype;
	_jc_soot_tagkit_DoubleConstantValueTag$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_DoubleConstantValueTag$vtype _jc_soot_tagkit_DoubleConstantValueTag$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_DoubleConstantValueTag, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_DoubleConstantValueTag$class_object;

#endif	/* _JC_soot_tagkit_DoubleConstantValueTag_H_ */
